@@ -5,6 +5,7 @@
 #----------------------------------------------------------------------#
 
 import os
+import glob
 import sys
 import ctypes
 import numpy as np
@@ -388,15 +389,14 @@ class hipofile:
         Description:
             Get a list of the entry names from the data table in the current event's bank.
         """
-        nEntries = self.getEntries(bankName)
-        data = (ctypes.c_char_p * nEntries)()
-        self.lib.hipo_get_bank_entries_names_(
+        hipo_get_bank_entries_names_ = self.lib.hipo_get_bank_entries_names_
+        hipo_get_bank_entries_names_.restype = ctypes.c_char_p
+        return hipo_get_bank_entries_names_(
             ctypes.c_char_p(bankName.encode('ascii')),
             ctypes.c_int(len(bankName)),
-            data
-        )
+        ).decode('ascii').split(' ')
 
-        return [data[i].decode('ascii') for i in range(nEntries)]
+        # return [data[i].decode('ascii') for i in range(nEntries)]
 
     def getTypes(self,bankName):
         """
@@ -553,7 +553,20 @@ class hipofileIterator:
 class hipochain:
 
     def __init__(self,names,banks="",step=100,mode="r"):
-        self.names   = names #TODO: Figure out how to parse REGEX expression to list
+        self.names   = names
+
+        # Parse regex NOTE: Must be full or relative path from $PWD.  ~/... does not work.
+        if type(self.names)==str:
+            self.names = glob.glob(names)
+        else:
+            newnames = []
+            for i in range(len(self.names)):
+                files = glob.glob(self.names(i))
+                if len(files>0):
+                    for file in files:
+                        self.newnames.append(file)
+            self.names = newnames
+
         self.banks   = banks if banks != "" else self.getBanks()
         self.step    = step
         self.mode    = "r"   #TODO: Does it make sense to just fix this?
